@@ -8,6 +8,10 @@ from .preprocessing import *
 from .transforms import *
 from .image import *
 from .tabular import *
-from .features import *
 from .mixed import *
-from .mixed_augmentation import *
\ No newline at end of file
+from .mixed_augmentation import *
+
+# Conditional import
+from ..imports import ExtraDependencies
+if ExtraDependencies.tsfresh:
+    from .features import *
\ No newline at end of file
