@@ -1,7 +1,6 @@
 from .layers import *
 from .utils import *
 from .explainability import *
-
 from .FCN import *
 from .FCNPlus import *
 from .TCN import *
@@ -17,8 +16,7 @@ from .RNN import *
 from .RNNPlus import *
 from .RNN_FCN import *
 from .RNN_FCNPlus import *
-from .ROCKET import *
-from .MINIROCKET import *
+from .ROCKET_Pytorch import *
 from .MINIROCKET_Pytorch import *
 from .MINIROCKETPlus_Pytorch import *
 from .TransformerModel import *
@@ -37,5 +35,10 @@ from .TabFusionTransformer import *
 from .TSPerceiver import *
 from .TSiTPlus import *
 from .MultiInputNet import *
+from .misc import *
 
-from .misc import *
\ No newline at end of file
+# Conditional import
+from ..imports import ExtraDependencies
+if ExtraDependencies.sktime:
+    from .ROCKET import *
+    from .MINIROCKET import *
\ No newline at end of file
